@@ -8,6 +8,7 @@
 #' @param gl Name of the genlight object containing the SNP genotypes by specimen and population [required]
 #' @param nfactors Number of dimensions to retain in the output file [default 5]
 #' @param v -- verbose if TRUE, silent if FALSE [default TRUE]
+#' @param parallel should parallel version be used (does fail under Windows)
 #' @import adegenet
 #' @return An object of class glPca containing the eigenvalues, factor scores and factor loadings
 #' @export
@@ -15,11 +16,11 @@
 #' @examples
 #' pcoa <- gl.pcoa(testset.gl, nfactors=3)
 
-gl.pcoa <- function(gl, nfactors=5, v=TRUE) {
+gl.pcoa <- function(gl, nfactors=5, v=TRUE, parallel=FALSE) {
 x <- gl
 
     if (v==TRUE) {cat("Performing a PCoA, individuals as entities, SNP loci as attributes\n")}
-    pcoa <- glPca(x, nf=nfactors, parallel=FALSE)
+    pcoa <- glPca(x, nf=nfactors, parallel=parallel)
 
     e <- pcoa$eig[pcoa$eig > sum(pcoa$eig/length(pcoa$eig))]
     e <- round(e*100/sum(pcoa$eig),1)
